==> org-lsst-ccs-subsystem-refrig-gui-4.4.4-sources.jar: org/lsst/ccs/subsystem/refrig/ui/ChillerControlPanel.java <==
package org.lsst.ccs.subsystem.refrig.ui;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.util.HashMap;
import java.util.Map;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
import javax.swing.SwingUtilities;
import org.lsst.ccs.subsystem.common.ui.SystemStatusPanel;
import org.lsst.ccs.subsystem.common.ui.TextFieldX;
import org.lsst.ccs.subsystem.common.ui.UiConstants;
import org.lsst.ccs.subsystem.common.ui.UiUtilities;
import org.lsst.ccs.subsystem.common.ui.jas.CommandSender;
import org.lsst.ccs.subsystem.refrig.constants.ChillerState;
import org.lsst.ccs.subsystem.refrig.constants.RefrigConstants;
import org.lsst.ccs.subsystem.refrig.data.ChillerControlState;

/**
 *  Implements the chiller control panel.
 *
 *  @author Owen Saxton
 */
public class ChillerControlPanel extends JPanel implements CommandSender.ReplyHandler, UiUtilities.ActionHandler  {

    private static final String CMND_GET_STATE = "getControlState";
    private static final Map<ChillerState, Color> stateColors = new HashMap<>();
    static {
        stateColors.put(ChillerState.OFFLINE, UiConstants.BLUE);
        stateColors.put(ChillerState.SETPOINT, UiConstants.GREEN);
        stateColors.put(ChillerState.CONTROLLING, UiConstants.YELLOW);
    }

    private final CommandSender sender;
    private final UiUtilities uiUtils;

    private SystemStatusPanel statusPanel;
    private JPanel mainPanel;
    private JPanel chillerStatePnl;
    private JPanel historyPanel;
    private JLabel chillerStateLbl;
    private TextFieldX flowRateTf;
    private TextFieldX tankPressTf;
    private TextFieldX rampRateTf;
    private TextFieldX tempSetPointTf;
    private JLabel controlModeLbl;
    private JLabel defaultRampLbl;
    private JLabel lastRampLbl;
    private TextFieldX tempWithRampTf;
    private JLabel RampRateLbl;
    private JButton quitControlBtn;
    private double flowRate, tankPress, tempSetPoint, rampRate;

    public ChillerControlPanel(String agent) {
        sender = new CommandSender(agent, this);
        uiUtils = new UiUtilities(this);
        initComponents();
        (new DisablePanel()).run();
    }

    public void initPanel() {
        sender.sendCommand(true, null, CMND_GET_STATE);
    }

    @Override
    public void onCommandReply(Object reply, String path, String command, Object[] args) {
        if (command.equals(CMND_GET_STATE)) {
            updatePanel((ChillerControlState)reply);
        }
        else if (reply != null) {
            System.out.println(reply.toString());
        }
    }

    @Override
    public void onCommandReject(String path, String command, Object[] args) {
        if (!command.equals(CMND_GET_STATE)) {
            sender.sendCommand(true, null, CMND_GET_STATE);
        }
    }

    @Override
    public void onCommandError(String path, String command, Object[] args) {
        if (!command.equals(CMND_GET_STATE)) {
            sender.sendCommand(true, null, CMND_GET_STATE);
        }
    }

    public void updatePanel(ChillerControlState cs) {
        SwingUtilities.invokeLater(new UpdateChillerState(cs));
    }

    public void disablePanel() {
        SwingUtilities.invokeLater(new DisablePanel());
    }

    private void initComponents() {

        // Individual graphic elements
        chillerStateLbl = UiUtilities.newLabel("XXXXX", UiUtilities.maxEnumLabelWidth(ChillerState.class));
        flowRateTf = uiUtils.newTextFieldX("999999.9", "F", TextFieldX.TYPE_DOUBLE);
        flowRateTf.update(flowRate, true);
        tankPressTf = uiUtils.newTextFieldX("999999.9", "P", TextFieldX.TYPE_DOUBLE);
        tankPressTf.update(tankPress, true);
        rampRateTf = uiUtils.newTextFieldX("999999.9", "R", TextFieldX.TYPE_DOUBLE);
        rampRateTf.update(rampRate, true);
        tempSetPointTf = uiUtils.newTextFieldX("999999.9", "T", TextFieldX.TYPE_DOUBLE);
        tempSetPointTf.update(tempSetPoint, true);
        controlModeLbl = UiUtilities.newLabel("99999.9", 0);
        controlModeLbl.setHorizontalAlignment(SwingConstants.CENTER);
        controlModeLbl.setText("");
        defaultRampLbl = UiUtilities.newLabel("99999.9", 0);
        defaultRampLbl.setHorizontalAlignment(SwingConstants.CENTER);
        defaultRampLbl.setText("0.0");
        lastRampLbl = UiUtilities.newLabel("99999.9", 0);
        lastRampLbl.setHorizontalAlignment(SwingConstants.CENTER);
        lastRampLbl.setText("0.0");
        tempWithRampTf = uiUtils.newTextFieldX("999999.9", "U", TextFieldX.TYPE_DOUBLE);
        tempWithRampTf.update(tempSetPoint, true);
        RampRateLbl = UiUtilities.newLabel("99999.9", 0);
        RampRateLbl.setHorizontalAlignment(SwingConstants.CENTER);
        RampRateLbl.setText(Double.toString(rampRate));
        quitControlBtn = uiUtils.newButton("Quit", "Q", false);

        // System status line panel
        statusPanel = new SystemStatusPanel(sender, RefrigConstants.MONITOR_CONTROL, true);

        // Chiller status line panel
        chillerStatePnl = new JPanel();
        chillerStatePnl.setLayout(new GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.anchor = GridBagConstraints.WEST;
        gbc.gridx = 0;
        gbc.gridy = 0;
        gbc.insets = new Insets(0, 4, 0, 4);
        chillerStatePnl.add(UiUtilities.newLabel("Chiller State:", 0), gbc);
        gbc.gridx++;
        chillerStatePnl.add(chillerStateLbl, gbc);
        gbc.gridx++;
        chillerStatePnl.add(UiUtilities.newLabel("Temperature-control from", 0), gbc);
        gbc.gridx++;
        chillerStatePnl.add(controlModeLbl, gbc);

        // History panel
        historyPanel = new JPanel();
        historyPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbh = new GridBagConstraints();
        gbh.anchor = GridBagConstraints.WEST;
        gbh.gridx = 0;
        gbh.gridy = 0;
        gbh.insets = new Insets(0, 4, 4, 4);
        historyPanel.add(UiUtilities.newLabel("Last-used ramp:", 0), gbh);
        gbh.gridx++;
        historyPanel.add(lastRampLbl, gbh);
        gbh.gridx++;
        gbh.gridwidth = 2;
        historyPanel.add(UiUtilities.newLabel("C/min", 0), gbh);
        gbh.gridwidth = 1;

        // Main panel
        mainPanel = new JPanel();
        mainPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbm = new GridBagConstraints();
        gbm.anchor = GridBagConstraints.WEST;
        gbm.insets = new Insets(0, 0, 4, 5);

        gbm.gridx = 0;
        gbm.gridy = 0;
        mainPanel.add(UiUtilities.newLabel("Set flow rate:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(flowRateTf, gbm);
        gbm.gridx++;
        gbm.gridwidth = 2;
        mainPanel.add(UiUtilities.newLabel("gal/min", 0), gbm);
        gbm.gridwidth = 1;

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set tank pressure:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(tankPressTf, gbm);
        gbm.gridx++;
        gbm.gridwidth = 2;
        mainPanel.add(UiUtilities.newLabel("psig", 0), gbm);
        gbm.gridwidth = 1;

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set specified ramp:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(rampRateTf, gbm);
        gbm.gridx++;
        gbm.gridwidth = 2;
        mainPanel.add(UiUtilities.newLabel("C/min", 0), gbm);
        gbm.gridwidth = 1;

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set temperature:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(tempSetPointTf, gbm);
        gbm.gridx++;
        gbm.insets.right = 20;
        mainPanel.add(UiUtilities.newLabel("C", 0), gbm);
        gbm.gridx ++;
        gbm.insets.right = 5;
        mainPanel.add(UiUtilities.newLabel("with default ramp:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(defaultRampLbl, gbm);
        gbm.gridx ++;
        mainPanel.add(UiUtilities.newLabel("C/min", 0), gbm);

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set temperature:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(tempWithRampTf, gbm);
        gbm.gridx ++;
        gbm.insets.right = 20;
        mainPanel.add(UiUtilities.newLabel("C", 0), gbm);
        gbm.gridx ++;
        gbm.insets.right = 5;
        mainPanel.add(UiUtilities.newLabel("with specified ramp:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(RampRateLbl, gbm);
        gbm.gridx ++;
        mainPanel.add(UiUtilities.newLabel("C/min", 0), gbm);

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Quit controlling:", 0), gbm);
        gbm.gridx ++;
        mainPanel.add(quitControlBtn, gbm);

        // Lay out the complete panel
        setLayout(new GridBagLayout());
        GridBagConstraints gbp = new GridBagConstraints();
        gbp.insets = new Insets(4, 4, 0, 0);
        gbp.anchor = GridBagConstraints.NORTH;
        gbp.gridx = 0;
        gbp.gridy = 0;
        add(statusPanel, gbp);
        gbp.gridy++;
        gbp.insets.bottom = 12;
        add(chillerStatePnl, gbp);
        gbp.gridy++;
        gbp.insets.bottom = 16;
        add(historyPanel, gbp);
        gbp.gridy++;
        gbp.insets.bottom = 4;
        add(mainPanel, gbp);
    }

    @Override
    public void handleTextFieldX(String name, Object value) {
        switch (name) {
        case "F":
            flowRate = (double)value;
            sender.sendCommand(true, null, "setFlow", flowRate);
            break;
        case "P":
            tankPress = (double)value;
            sender.sendCommand(null, "setTankPressure", tankPress);
            break;
        case "T":
            tempSetPoint = (double)value;
            sender.sendCommand(null, "setTemperature", tempSetPoint);
            break;
        case "U":
            tempSetPoint = (double)value;
            sender.sendCommand(null, "setTemperatureWithRamp", tempSetPoint, rampRate);
            break;
        case "R":
            rampRate = (double)value;
            rampRateTf.update(rampRate, true);
            RampRateLbl.setText(Double.toString(rampRate));
            break;
        }
    }

    @Override
    public void handleButton(String name) {
        switch (name) {
        case "Q":
            sender.sendCommand(null, "quitControllingTemperature");
            break;
        }
    }

    class UpdateChillerState implements Runnable {

        private final ChillerControlState cs;

        UpdateChillerState(ChillerControlState cs) {
            this.cs = cs;
        }

        @Override
        public void run() {
            statusPanel.updatePanel(cs.getFastPeriod());
            chillerStateLbl.setText(cs.getChillerState().name());
            chillerStateLbl.setForeground(stateColors.getOrDefault(cs.getChillerState(), Color.BLACK));
            if (!Double.isNaN(cs.getFlowSet())) {
                flowRate = cs.getFlowSet();
            }
            flowRateTf.update(flowRate, true);
            if (!Double.isNaN(cs.getTankSet())) {
                tankPress = cs.getTankSet();
            }
            tankPressTf.update(tankPress, true);
            if (!Double.isNaN(cs.getSetPoint())) {
                tempSetPoint = cs.getSetPoint();
            }
            tempSetPointTf.update(tempSetPoint, true);
            if (!Double.isNaN(cs.getDefaultRamp())) {
                defaultRampLbl.setText(String.valueOf(cs.getDefaultRamp()));
            }
            controlModeLbl.setText(cs.getTemperatureMode());
            lastRampLbl.setText(String.valueOf(cs.getLastRamp()));
            tempWithRampTf.update(tempSetPoint, true);
            rampRateTf. update(rampRate, true);
            quitControlBtn.setEnabled(true);
            repaint();
        }

    }

    class DisablePanel implements Runnable {

        @Override
        public void run() {
            statusPanel.disablePanel();
            flowRateTf.setDisabled();
            tankPressTf.setDisabled();
            tempSetPointTf.setDisabled();
            tempWithRampTf.setDisabled();
            rampRateTf.setDisabled();
            quitControlBtn.setEnabled(false);
            repaint();
        } 
    }

    private static final long serialVersionUID = 1L;
}

==> org-lsst-ccs-subsystem-refrig-gui-4.4.6-sources.jar: org/lsst/ccs/subsystem/refrig/ui/ChillerControlPanel.java <==
package org.lsst.ccs.subsystem.refrig.ui;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.util.HashMap;
import java.util.Map;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
import javax.swing.SwingUtilities;
import org.lsst.ccs.subsystem.common.ui.SystemStatusPanel;
import org.lsst.ccs.subsystem.common.ui.TextFieldX;
import org.lsst.ccs.subsystem.common.ui.UiConstants;
import org.lsst.ccs.subsystem.common.ui.UiUtilities;
import org.lsst.ccs.subsystem.common.ui.jas.CommandSender;
import org.lsst.ccs.subsystem.refrig.constants.ChillerState;
import org.lsst.ccs.subsystem.refrig.constants.RefrigConstants;
import org.lsst.ccs.subsystem.refrig.data.ChillerControlState;

/**
 *  Implements the chiller control panel.
 *
 *  @author Owen Saxton
 */
public class ChillerControlPanel extends JPanel implements CommandSender.ReplyHandler, UiUtilities.ActionHandler  {

    private static final String CMND_GET_STATE = "getControlState";
    private static final Map<ChillerState, Color> stateColors = new HashMap<>();
    static {
        stateColors.put(ChillerState.OFFLINE, UiConstants.BLUE);
        stateColors.put(ChillerState.SETPOINT, UiConstants.GREEN);
        stateColors.put(ChillerState.CONTROLLING, UiConstants.YELLOW);
    }

    private final CommandSender sender;
    private final UiUtilities uiUtils;

    private SystemStatusPanel statusPanel;
    private JPanel mainPanel;
    private JPanel chillerStatePnl;
    private JPanel historyPanel;
    private JLabel chillerStateLbl;
    private TextFieldX flowRateTf;
    private TextFieldX tankPressTf;
    private TextFieldX rampRateTf;
    private TextFieldX tempSetPointTf;
    private JLabel controlModeLbl;
    private JLabel defaultRampLbl;
    private JLabel lastRampLbl;
    private TextFieldX tempWithRampTf;
    private JLabel RampRateLbl;
    private JButton quitControlBtn;
    private double flowRate, tankPress, tempSetPoint, rampRate;

    public ChillerControlPanel(String agent) {
        sender = new CommandSender(agent, this);
        uiUtils = new UiUtilities(this);
        initComponents();
        (new DisablePanel()).run();
    }

    public void initPanel() {
        sender.sendCommand(true, null, CMND_GET_STATE);
    }

    @Override
    public void onCommandReply(Object reply, String path, String command, Object[] args) {
        if (command.equals(CMND_GET_STATE)) {
            updatePanel((ChillerControlState)reply);
        }
        else if (reply != null) {
            System.out.println(reply.toString());
        }
    }

    @Override
    public void onCommandReject(String path, String command, Object[] args) {
        if (!command.equals(CMND_GET_STATE)) {
            sender.sendCommand(true, null, CMND_GET_STATE);
        }
    }

    @Override
    public void onCommandError(String path, String command, Object[] args) {
        if (!command.equals(CMND_GET_STATE)) {
            sender.sendCommand(true, null, CMND_GET_STATE);
        }
    }

    public void updatePanel(ChillerControlState cs) {
        SwingUtilities.invokeLater(new UpdateChillerState(cs));
    }

    public void disablePanel() {
        SwingUtilities.invokeLater(new DisablePanel());
    }

    private void initComponents() {

        // Individual graphic elements
        chillerStateLbl = UiUtilities.newLabel("XXXXX", UiUtilities.maxEnumLabelWidth(ChillerState.class));
        flowRateTf = uiUtils.newTextFieldX("999999.9", "F", TextFieldX.TYPE_DOUBLE);
        flowRateTf.update(flowRate, true);
        tankPressTf = uiUtils.newTextFieldX("999999.9", "P", TextFieldX.TYPE_DOUBLE);
        tankPressTf.update(tankPress, true);
        rampRateTf = uiUtils.newTextFieldX("999999.9", "R", TextFieldX.TYPE_DOUBLE);
        rampRateTf.update(rampRate, true);
        tempSetPointTf = uiUtils.newTextFieldX("999999.9", "T", TextFieldX.TYPE_DOUBLE);
        tempSetPointTf.update(tempSetPoint, true);
        controlModeLbl = UiUtilities.newLabel("99999.9", 0);
        controlModeLbl.setHorizontalAlignment(SwingConstants.CENTER);
        controlModeLbl.setText("");
        defaultRampLbl = UiUtilities.newLabel("99999.9", 0);
        defaultRampLbl.setHorizontalAlignment(SwingConstants.CENTER);
        defaultRampLbl.setText("0.0");
        lastRampLbl = UiUtilities.newLabel("99999.9", 0);
        lastRampLbl.setHorizontalAlignment(SwingConstants.CENTER);
        lastRampLbl.setText("0.0");
        tempWithRampTf = uiUtils.newTextFieldX("999999.9", "U", TextFieldX.TYPE_DOUBLE);
        tempWithRampTf.update(tempSetPoint, true);
        RampRateLbl = UiUtilities.newLabel("99999.9", 0);
        RampRateLbl.setHorizontalAlignment(SwingConstants.CENTER);
        RampRateLbl.setText(Double.toString(rampRate));
        quitControlBtn = uiUtils.newButton("Quit", "Q", false);

        // System status line panel
        statusPanel = new SystemStatusPanel(sender, RefrigConstants.MONITOR_CONTROL, true);

        // Chiller status line panel
        chillerStatePnl = new JPanel();
        chillerStatePnl.setLayout(new GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.anchor = GridBagConstraints.WEST;
        gbc.gridx = 0;
        gbc.gridy = 0;
        gbc.insets = new Insets(0, 4, 0, 4);
        chillerStatePnl.add(UiUtilities.newLabel("Chiller State:", 0), gbc);
        gbc.gridx++;
        chillerStatePnl.add(chillerStateLbl, gbc);
        gbc.gridx++;
        chillerStatePnl.add(UiUtilities.newLabel("Temperature-control from", 0), gbc);
        gbc.gridx++;
        chillerStatePnl.add(controlModeLbl, gbc);

        // History panel
        historyPanel = new JPanel();
        historyPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbh = new GridBagConstraints();
        gbh.anchor = GridBagConstraints.WEST;
        gbh.gridx = 0;
        gbh.gridy = 0;
        gbh.insets = new Insets(0, 4, 4, 4);
        historyPanel.add(UiUtilities.newLabel("Current or most-recent ramp:", 0), gbh);
        gbh.gridx++;
        historyPanel.add(lastRampLbl, gbh);
        gbh.gridx++;
        gbh.gridwidth = 2;
        historyPanel.add(UiUtilities.newLabel("C/min", 0), gbh);
        gbh.gridwidth = 1;

        // Main panel
        mainPanel = new JPanel();
        mainPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbm = new GridBagConstraints();
        gbm.anchor = GridBagConstraints.WEST;
        gbm.insets = new Insets(0, 0, 4, 5);

        gbm.gridx = 0;
        gbm.gridy = 0;
        mainPanel.add(UiUtilities.newLabel("Set flow rate:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(flowRateTf, gbm);
        gbm.gridx++;
        gbm.gridwidth = 2;
        mainPanel.add(UiUtilities.newLabel("gal/min", 0), gbm);
        gbm.gridwidth = 1;

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set tank pressure:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(tankPressTf, gbm);
        gbm.gridx++;
        gbm.gridwidth = 2;
        mainPanel.add(UiUtilities.newLabel("psig", 0), gbm);
        gbm.gridwidth = 1;

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set specified ramp:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(rampRateTf, gbm);
        gbm.gridx++;
        gbm.gridwidth = 2;
        mainPanel.add(UiUtilities.newLabel("C/min", 0), gbm);
        gbm.gridwidth = 1;

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set temperature:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(tempSetPointTf, gbm);
        gbm.gridx++;
        gbm.insets.right = 20;
        mainPanel.add(UiUtilities.newLabel("C", 0), gbm);
        gbm.gridx ++;
        gbm.insets.right = 5;
        mainPanel.add(UiUtilities.newLabel("with default ramp:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(defaultRampLbl, gbm);
        gbm.gridx ++;
        mainPanel.add(UiUtilities.newLabel("C/min", 0), gbm);

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Set temperature:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(tempWithRampTf, gbm);
        gbm.gridx ++;
        gbm.insets.right = 20;
        mainPanel.add(UiUtilities.newLabel("C", 0), gbm);
        gbm.gridx ++;
        gbm.insets.right = 5;
        mainPanel.add(UiUtilities.newLabel("with specified ramp:", 0), gbm);
        gbm.gridx++;
        mainPanel.add(RampRateLbl, gbm);
        gbm.gridx ++;
        mainPanel.add(UiUtilities.newLabel("C/min", 0), gbm);

        gbm.gridx = 0;
        gbm.gridy++;
        mainPanel.add(UiUtilities.newLabel("Quit controlling:", 0), gbm);
        gbm.gridx ++;
        mainPanel.add(quitControlBtn, gbm);

        // Lay out the complete panel
        setLayout(new GridBagLayout());
        GridBagConstraints gbp = new GridBagConstraints();
        gbp.insets = new Insets(4, 4, 0, 0);
        gbp.anchor = GridBagConstraints.NORTH;
        gbp.gridx = 0;
        gbp.gridy = 0;
        add(statusPanel, gbp);
        gbp.gridy++;
        gbp.insets.bottom = 12;
        add(chillerStatePnl, gbp);
        gbp.gridy++;
        gbp.insets.bottom = 16;
        add(historyPanel, gbp);
        gbp.gridy++;
        gbp.insets.bottom = 4;
        add(mainPanel, gbp);
    }

    @Override
    public void handleTextFieldX(String name, Object value) {
        switch (name) {
        case "F":
            flowRate = (double)value;
            sender.sendCommand(true, null, "setFlow", flowRate);
            break;
        case "P":
            tankPress = (double)value;
            sender.sendCommand(null, "setTankPressure", tankPress);
            break;
        case "T":
            tempSetPoint = (double)value;
            sender.sendCommand(null, "setTemperature", tempSetPoint);
            break;
        case "U":
            tempSetPoint = (double)value;
            sender.sendCommand(null, "setTemperatureWithRamp", tempSetPoint, rampRate);
            break;
        case "R":
            rampRate = (double)value;
            rampRateTf.update(rampRate, true);
            RampRateLbl.setText(Double.toString(rampRate));
            break;
        }
    }

    @Override
    public void handleButton(String name) {
        switch (name) {
        case "Q":
            sender.sendCommand(null, "quitControllingTemperature");
            break;
        }
    }

    class UpdateChillerState implements Runnable {

        private final ChillerControlState cs;

        UpdateChillerState(ChillerControlState cs) {
            this.cs = cs;
        }

        @Override
        public void run() {
            statusPanel.updatePanel(cs.getFastPeriod());
            chillerStateLbl.setText(cs.getChillerState().name());
            chillerStateLbl.setForeground(stateColors.getOrDefault(cs.getChillerState(), Color.BLACK));
            if (!Double.isNaN(cs.getFlowSet())) {
                flowRate = cs.getFlowSet();
            }
            flowRateTf.update(flowRate, true);
            if (!Double.isNaN(cs.getTankSet())) {
                tankPress = cs.getTankSet();
            }
            tankPressTf.update(tankPress, true);
            if (!Double.isNaN(cs.getSetPoint())) {
                tempSetPoint = cs.getSetPoint();
            }
            tempSetPointTf.update(tempSetPoint, true);
            if (!Double.isNaN(cs.getDefaultRamp())) {
                defaultRampLbl.setText(String.valueOf(cs.getDefaultRamp()));
            }
            controlModeLbl.setText(cs.getTemperatureMode());
            lastRampLbl.setText(String.valueOf(cs.getLastRamp()));
            tempWithRampTf.update(tempSetPoint, true);
            rampRateTf. update(rampRate, true);
            quitControlBtn.setEnabled(true);
            repaint();
        }

    }

    class DisablePanel implements Runnable {

        @Override
        public void run() {
            statusPanel.disablePanel();
            flowRateTf.setDisabled();
            tankPressTf.setDisabled();
            tempSetPointTf.setDisabled();
            tempWithRampTf.setDisabled();
            rampRateTf.setDisabled();
            quitControlBtn.setEnabled(false);
            repaint();
        } 
    }

    private static final long serialVersionUID = 1L;
}
